package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcCarExpenseMapper;
import com.ruoyi.oa.domain.CmcCarExpense;
import com.ruoyi.oa.service.ICmcCarExpenseService;

/**
 * cmc车辆费用Service业务层处理
 * 
 * @author cmc
 * @date 2024-03-12
 */
@Service
public class CmcCarExpenseServiceImpl implements ICmcCarExpenseService 
{
    @Autowired
    private CmcCarExpenseMapper cmcCarExpenseMapper;

    /**
     * 查询cmc车辆费用
     * 
     * @param carExpenseId cmc车辆费用主键
     * @return cmc车辆费用
     */
    @Override
    public CmcCarExpense selectCmcCarExpenseByCarExpenseId(String carExpenseId)
    {
        return cmcCarExpenseMapper.selectCmcCarExpenseByCarExpenseId(carExpenseId);
    }

    /**
     * 查询cmc车辆费用列表
     * 
     * @param cmcCarExpense cmc车辆费用
     * @return cmc车辆费用
     */
    @Override
    public List<CmcCarExpense> selectCmcCarExpenseList(CmcCarExpense cmcCarExpense)
    {
        return cmcCarExpenseMapper.selectCmcCarExpenseList(cmcCarExpense);
    }

    /**
     * 新增cmc车辆费用
     * 
     * @param cmcCarExpense cmc车辆费用
     * @return 结果
     */
    @Override
    public int insertCmcCarExpense(CmcCarExpense cmcCarExpense)
    {
        return cmcCarExpenseMapper.insertCmcCarExpense(cmcCarExpense);
    }

    /**
     * 修改cmc车辆费用
     * 
     * @param cmcCarExpense cmc车辆费用
     * @return 结果
     */
    @Override
    public int updateCmcCarExpense(CmcCarExpense cmcCarExpense)
    {
        return cmcCarExpenseMapper.updateCmcCarExpense(cmcCarExpense);
    }

    /**
     * 批量删除cmc车辆费用
     * 
     * @param carExpenseIds 需要删除的cmc车辆费用主键
     * @return 结果
     */
    @Override
    public int deleteCmcCarExpenseByCarExpenseIds(String[] carExpenseIds)
    {
        return cmcCarExpenseMapper.deleteCmcCarExpenseByCarExpenseIds(carExpenseIds);
    }

    /**
     * 删除cmc车辆费用信息
     * 
     * @param carExpenseId cmc车辆费用主键
     * @return 结果
     */
    @Override
    public int deleteCmcCarExpenseByCarExpenseId(String carExpenseId)
    {
        return cmcCarExpenseMapper.deleteCmcCarExpenseByCarExpenseId(carExpenseId);
    }
}
